@@ -42,9 +42,7 @@ class Namespace(object):
             base_namespace = self
 
         if not os.path.isdir(directory):
-            log_warn("Test directory not found (%s). Use -p to specify test search path" % directory)
-            # raise SomeThing
-            return
+            die("Test directory not found (%s). Use -p to specify test search path" % directory)
 
         self.base = base_namespace
         self.scan_for_tests()
@@ -526,6 +524,7 @@ def main(argv=None):
         try: 
             global CONFIG_OVERRIDE_SCRIPT 
             CONFIG_OVERRIDE_SCRIPT = read_configuration(options.config_file)
+            log_info("Loaded global config overrides: %s" % options.config_file)
         except IOError, msg:
             die(msg)
 
